==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/nb.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Passordet må være på minst %s tegn",
    "Password needs to contain at least one lower and one upper case character." : "Passordet må inneholde minst en liten og en stor bokstav.",
    "Password needs to contain at least one numeric character." : "Passordet må inneholde minst ett numerisk tegn.",
    "Password needs to contain at least one special character." : "Passordet må inneholde minst ett spesialtegn.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Passordet er blant de 1 000 000 mest brukte passordene. Gjør det unikt.",
    "Password policy" : "Passordregler",
    "Minimal length" : "Minste lenge",
    "Forbid common passwords" : "Forby mest brukte passord",
    "Enforce upper and lower case characters" : "Tving stor og liten bokstav",
    "Enforce numeric characters" : "Tving numerisk tegn",
    "Enforce special characters" : "Tving spesialtegn",
    "Password need to be at least %s characters long" : "Passordet må være på minst %s tegn",
    "Password need to contain at least one lower case character and one upper case character." : "Passordet må inneholde minst en liten og en stor bokstav",
    "Password need to contain at least one numeric character." : "Passordet må inneholde minst et numerisk tegn",
    "Password need to contain at least one special character." : "Passordet må inneholde minst et spesialtegn",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Passordet er blant de 1 000 000 mest brukte passordene. Velg et annet passord."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/nb.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Passordet må være på minst %s tegn",
    "Password needs to contain at least one lower and one upper case character." : "Passordet må inneholde minst en liten og en stor bokstav.",
    "Password needs to contain at least one numeric character." : "Passordet må inneholde minst ett numerisk tegn.",
    "Password needs to contain at least one special character." : "Passordet må inneholde minst ett spesialtegn.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Passordet er blant de 1 000 000 mest brukte passordene. Gjør det unikt.",
    "Password policy" : "Passordregler",
    "Minimal length" : "Minste lengde",
    "Forbid common passwords" : "Forby mest brukte passord",
    "Enforce upper and lower case characters" : "Tving stor og liten bokstav",
    "Enforce numeric characters" : "Tving numerisk tegn",
    "Enforce special characters" : "Tving spesialtegn",
    "Password need to be at least %s characters long" : "Passordet må være på minst %s tegn",
    "Password need to contain at least one lower case character and one upper case character." : "Passordet må inneholde minst en liten og en stor bokstav",
    "Password need to contain at least one numeric character." : "Passordet må inneholde minst et numerisk tegn",
    "Password need to contain at least one special character." : "Passordet må inneholde minst et spesialtegn",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Passordet er blant de 1 000 000 mest brukte passordene. Velg et annet passord."
},
"nplurals=2; plural=(n != 1);");
